---
name: usethis-qa-static-checks
description: Perform static code checks
compatibility: usethis, Python, prek, basedpyright
license: MIT
metadata:
  version: "1.1"
---

# Static Checks

To perform static checks on the codebase, run:

```bash
uv run prek run -a
uv run basedpyright
```
